# Program to generate a scatter plot, data is read from a CSV file 

def read_CSV():
    """Function to read a CSV file and return two columns"""
    import numpy as np
     
    # Reads input file name 
    my_input_file = input("Type CSV file name => ")
    
    # Reads CSV file
    my_csv = np.genfromtxt (my_input_file, delimiter=",", skip_header = 1)

    # Gets each column from CSV file
    x = my_csv[:,0]
    y = my_csv[:,1]
    
    return x,y

def convert2scikit(x):
    """Function to convert array to scikit-learn format"""
    # Set up empty lists
    X = []
    list0 = []
    
    # Looping through x
    for line in x:
        # Converts element to list
        list0.append(line)
        # Append list to list
        X.append(list0)
        list0 = []
    
    # Return new array
    return X

def simple_linear_regression1(x_in,y_in):
    """Function to generate a linear regression model for one explanatory variable
    and their response variable. This function uses sklearn.linear_model.LinearRegression method."""
    # Import library
    from sklearn import linear_model
    import numpy as np
        
    # Create and fit the model
    model = linear_model.LinearRegression()
    model.fit(x_in, y_in)
    
    # Get Linear  Model 
    alpha1 = float(model.coef_)
    const = float(model.intercept_)
    z = np.array([alpha1,const])
    p = np.poly1d(z)
    
    print("\nBest fit linear regression model: ",p)
        
    return p

def gen_scatter_plot2(x,y,p,x_label,y_label,title,output_file):
    """Function to generate scatter plot"""
    import matplotlib.pyplot as plt
    
    # Generates plot
    plt.scatter(x,y) 
    
    # Title
    plt.title(title)
    
    # X-axis label
    plt.xlabel(x_label)
    
    # Y-axis label
    plt.ylabel(y_label)
    
    # Grid
    plt.grid(True)
    
    # Generates plot
    plt.plot(x, p(x), '-')

    # Shows plot
    plt.show()

    # Saves plot on png file
    plt.savefig(output_file)

def main():
    
    # Call read_CSV() function
    x,y = read_CSV()
    
    # Call convert2scikit(x)
    xs = convert2scikit(x)
    ys = convert2scikit(y)
    
    # Call simple_linear_regression1()
    p = simple_linear_regression1(xs,ys)
    
    # Predict the price for 30 cm pizza
    pred = p(30)
    print("Predicted price for 30 cm pizza (R$): %.2f"%pred)

    # Call gen_scatter_plot2()
    gen_scatter_plot2(x,y,p,"Diameter (cm)","R$","Pizza Price vs Diameter","pizza2.png")

main()