# Program to generate a scatter plot, data is read from a CSV file 

def read_CSV_3cols():
    """Function to read a CSV file and return three columns"""
    import numpy as np
     
    # Reads input file name 
    my_input_file = input("Type CSV file name => ")
    
    # Reads CSV file
    my_csv = np.genfromtxt (my_input_file, delimiter=",", skip_header = 1)

    # Gets each column from CSV file
    x1 = my_csv[:,0]
    x2 = my_csv[:,1]
    y = my_csv[:,2]
    
    return x1,x2,y

def convert2scikit(x):
    """Function to convert array to scikit-learn format"""
    # Set up empty lists
    X = []
    list0 = []
    
    # Looping through x
    for line in x:
        # Converts element to list
        list0.append(line)
        # Append list to list
        X.append(list0)
        list0 = []
    
    # Return new array
    return X

def make_2d_array(x1,x2):
    """Function to make 2-d array"""
    import numpy as np
    
    # Set up number of columns and rows
    number_columns = 2
    number_rows = len(x1)
    
    # Set up zero matrix
    X= [[0]*number_columns for i in range(number_rows)] 
    
    # Get matrix
    for i in range(number_rows):
        X[i][0] = x1[i]
        X[i][1] = x2[i]
    
    return X

def multiple_linear_regression(x_in,y_in,x_test,y_test):
    """Function to generate a linear regression model for one explanatory variable
    and their response variable. This function uses sklearn.linear_model.LinearRegression method."""
    # Import library
    from sklearn import linear_model
    import numpy as np
        
    # Create and fit the model
    model = linear_model.LinearRegression()
    model.fit(x_in, y_in)
    
    # Get Linear  Model 
    alpha1 = model.coef_[0][0]
    alpha2 = model.coef_[0][1]
    const = float(model.intercept_)
    z = np.array([alpha1,alpha2,const])
    p = np.poly1d(z)
    r_square = model.score(x_test, y_test)
    print("\nBest fit linear regression model: ",p)
    print('R-squared: %.4f' % r_square)
        
    return p

def main():
    
    # Call read_CSV_3cols() function
    x1,x2,y1 = read_CSV_3cols()
    
    # Call convert2scikit()
    ytr = convert2scikit(y1)
        
    # Call make_2d_array()
    Xtr = make_2d_array(x1,x2) 
        
    # Call read_CSV_3cols() function again
    x1,x2,y2 = read_CSV_3cols()
    
    # Call convert2scikit(x) again
    yte = convert2scikit(y2)
    
    # Call make_2d_array()
    Xte = make_2d_array(x1,x2) 
    
    # Call multiple_linear_regression()
    p = multiple_linear_regression(Xtr,ytr,Xte,yte)
    
    # Prediction of the price for 40 cm pizza
    y = p[0] + p[1]*2.0 + p[2]*40.0
    print("\nPredicted price for 40 cm pizza: %6.2f"%y)
    
main()