# Program to generate a scatter plot, data is read from a CSV file and a fitting polynomial equation is determined.
# The degree for the polynomial equation is given as input.


def read_csv():
    """Function to read csv"""
    
    import numpy as np

    # Reads input file name and polynomial equation degree
    my_input_file = input("Type CSV file name => ")
    my_deg = int(input("Type polynomial equation degree => "))

    # Reads CSV file
    my_csv = np.genfromtxt (my_input_file, delimiter=",", skip_header = 1)

    # Gets each column from CSV file
    x = my_csv[:,0]
    y = my_csv[:,1]

    return x,y,my_deg
    
def lsq(x,y,my_deg):
    """Function to generate regression model"""
    
    import numpy as np
    
    # Least-squares polynomial fitting 
    z = np.polyfit(x,y, my_deg)
    p = np.poly1d(z)
    rsquare = (np.corrcoef(y,p(x))[0,1] )**2
    print("\nBest fit polynomial equation: ",p,", R^2 = ",rsquare) 
        
    return p

def gen_plot(x,y,p):
    """Function to generate plot"""
    
    import matplotlib.pyplot as plt
    
    # Generates plot
    plt.scatter(x,y) 
    
    # Generates plot
    plt.plot(x, p(x), '-')

    # Shows plot
    plt.show()

    # Saves plot on png file
    plt.savefig('qsar1.png')
    
def main():
    
    # Call read_csv()
    x,y,my_deg = read_csv()
    
    # Call lsq()
    p = lsq(x,y,my_deg)
    
    # Call gen_plot()
    gen_plot(x,y,p)

main()